@@ -1,4 +1,3 @@
-
 `ade2vegancca` <-
     function(object)
 {
@@ -6,16 +5,14 @@
     CCA <- list(eig = object$eig,
                 u = as.matrix(object$l1),
                 v = as.matrix(object$c1),
-                u.eig = as.matrix(object$li),
-                v.eig = as.matrix(object$co),
-                wa.eig = as.matrix(object$ls),
+                wa = sweep(as.matrix(object$ls), 2,
+                           1/sqrt(object$eig[1:nf]), "*"),
                 biplot = as.matrix(object$cor)[-1,],
                 rank = object$rank,
                 tot.chi = sum(object$eig),
                 QR = NA,
                 envcentre = NA,
                 Xbar = NA)
-    CCA$wa <- sweep(CCA$wa.eig, 2, 1/sqrt(object$eig[1:nf]), "*")
     out <- list(call = object$call,
                 grand.total = NA,
                 rowsum = object$lw,
