@@ -1,7 +1,9 @@
 ### R 2.13.0 introduces nobs() method to get the number of
 ### observations. This file provides methods for vegan classes.
 
-`nobs.adonis` <- function(object, ...) NROW(object$coef.sites)
+`nobs.adonis` <- function(object, ...) NCOL(object$coef.sites)
+
+`nobs.anova.cca` <- function(object, ...) NA
 
 `nobs.betadisper` <- function(object, ...) length(object$distances)
 
