@@ -3,7 +3,7 @@
     function(x, ...)
 {
     out <- NULL
-    for(i in 1:length(x))
+    for(i in seq_along(x))
         out <- rbind(out, x[[i]])
     hulls <- rep(names(x), sapply(x, function(z) NROW(z)))
     attr(out, "hulls") <- hulls
