@@ -1,5 +1,5 @@
 `spenvcor` <-
-    function (object) 
+    function (object)
 {
     if (is.null(object$CCA))
         stop("Needs results from constrained ordination")
@@ -7,9 +7,11 @@
     wa <- object$CCA$wa
     if (!inherits(object, "rda")) { # is CCA
         r <- sqrt(object$rowsum)
-        u <- sweep(u, 1, r, "*")
-        wa <- sweep(wa, 1, r, "*")
+        u <- r * u
+        wa <- r * wa
     }
-    diag(cor(u, wa))
+    ## because colSums(u*u) = 1, we can simplify diag(cor(u, wa)) --
+    ## and we must for weighted CA
+    colSums(u * wa)/sqrt(colSums(wa^2))
 }
 
